scriptName mineorescript extends objectReference
;
;This script handles the Ore Veins and handshakes with the mining furniture
;===================================================================


sound property DrScOreOpen auto
{sound played when Ore is acquired}

formlist property mineOreToolsList auto
{Optional: Player must have at least one item from this formlist to interact}

Message Property FailureMessage Auto  
{Message to say why you can't use this without RequiredWeapon}

Message Property DepletedMessage Auto  
{Message to say that this vein is depleted}

MiscObject Property Ore Auto  
{what you get from this Ore Vein}

LeveledItem property lItemGems10 auto
{Optional: Gems that may be mined along with ore}

int Property ResourceCount = 1 Auto
{how many resources you get per drop}

int property ResourceCountTotal = 3 auto
{how many resources this has before it is depleted}

int property ResourceCountCurrent = -1 auto Hidden
{Used to track the current remaining resources}

int property StrikesBeforeCollection = 1 Auto
{how many times this is struck before giving a resource}

int property StrikesCurrent = -1 Auto hidden
{Current number of strikes}

int property AttackStrikesBeforeCollection = 3 Auto
{how many times this is struck by attacks before giving a resource}

int property AttackStrikesCurrent = -1 Auto hidden
{Current number of attack strikes}

mineOreFurnitureScript property myFurniture auto hidden
{the furniture for this piece of ore, set in script}

objectReference property objSelf auto hidden
{objectReference to self}

AchievementsScript property AchievementsQuest auto

Location Property CidhnaMineLocation Auto

Quest Property MS02 Auto

Quest Property DialogueCidhnaMine Auto

ObjectReference Property CidhnaMinePlayerBedREF Auto

;===================================================================
;;EVENT BLOCK
;===================================================================
event onCellAttach()
	blockActivation()
	SetNoFavorAllowed()
	objSelf = self as objectReference
	if !getLinkedRef()
		depleteOreDueToFailure()
	endif
endEvent

event onActivate(objectReference akActivator)
	if akActivator as actor
		if akActivator == game.getPlayer()

			If ResourceCountCurrent == 0
				DepletedMessage.Show()
			elseif playerHasTools() == false
				FailureMessage.Show()
			else
				If Game.GetPlayer().GetCurrentLocation() == CidhnaMineLocation && MS02.ISRunning() == False
					CidhnaMinePlayerBedREF.Activate(Game.GetPlayer())
					DialogueCidhnaMine.SetStage(45)
					Return
				EndIf
				if getLinkedRef()
					AchievementsQuest.incHardworker(2)
					giveOre()
				endif
			endif
		Else
			if getLinkedRef()
				getLinkedRef().activate(akActivator)
			endif
		EndIf
	EndIf
endEvent

event onReset()
	self.Reset()
	self.clearDestruction()
	self.setDestroyed(False)
	resourceCountCurrent = -1
endEvent

;===================================================================
;;FUNCTION BLOCK
;===================================================================
bool function playerHasTools()
	if Game.GetPlayer().GetItemCount(mineOreToolsList) > 0
		return true
	Else
		return false
	endIf
endFunction


function depleteOreDueToFailure()
	self.damageObject(50)
	self.setDestroyed(true)
	ResourceCountCurrent = 0
endFunction

function giveOre()
	; If there are not more resource, return
	If ResourceCountCurrent == 0
		DepletedMessage.Show()
		Return 
	endIf

	; If the current resource count is -1, reset it
	if ResourceCountCurrent <= -1
		ResourceCountCurrent = ResourceCountTotal
	endIf

	; If we are dealing with too many resources
	if ResourceCountTotal >= 100
		if ore
			(game.getPlayer()).addItem(Ore, 10)
		endif
		ResourceCountCurrent -= 10
	Else
		if ore
			(game.getPlayer()).addItem(Ore, ResourceCountTotal)
		endif

		; Give Gems while lowering current
		while ResourceCountCurrent > 0
			if lItemGems10
				(game.getPlayer()).addItem(lItemGems10)
			endif
			ResourceCountCurrent -= 1
		endWhile

		; Set it again, doesnt hurt
		ResourceCountCurrent = 0
	EndIf
	
	; If the resource is empty, destory it
	if ResourceCountCurrent == 0
		self.damageObject(50)
		DrScOreOpen.play(self)
		self.setDestroyed(true)
	Else
		DrScOreOpen.play(self)
	Endif
endFunction